@@ -17,8 +17,8 @@ log = logging.getLogger(__name__)
 LINT_DEBOUNCE_S = 0.5  # 500 ms
 PARENT_PROCESS_WATCH_INTERVAL = 10  # 10 s
 MAX_WORKERS = 64
-# We also watch for changes in config files
-PYTHON_FILE_EXTENSIONS = ('.py', '.pyi', 'pycodestyle.cfg', 'setup.cfg', 'tox.ini', '.flake8')
+PYTHON_FILE_EXTENSIONS = ('.py', '.pyi')
+CONFIG_FILEs = ('pycodestyle.cfg', 'setup.cfg', 'tox.ini', '.flake8')
 
 
 class _StreamHandlerWrapper(socketserver.StreamRequestHandler, object):
@@ -157,7 +157,8 @@ class PythonLanguageServer(MethodDispatcher):
             rootUri = uris.from_fs_path(rootPath) if rootPath is not None else ''
 
         self.workspace = Workspace(rootUri, self._endpoint)
-        self.config = config.Config(rootUri, initializationOptions or {}, processId)
+        self.config = config.Config(rootUri, initializationOptions or {},
+                                    processId, _kwargs.get('capabilities', {}))
         self._dispatchers = self._hook('pyls_dispatchers')
         self._hook('pyls_initialize')
 
@@ -300,12 +301,20 @@ class PythonLanguageServer(MethodDispatcher):
             self.lint(doc_uri, is_saved=False)
 
     def m_workspace__did_change_watched_files(self, changes=None, **_kwargs):
-        changed_py_files = set(d['uri'] for d in changes if d['uri'].endswith(PYTHON_FILE_EXTENSIONS))
-        # Only externally changed python files and lint configs may result in changed diagnostics.
-        if not changed_py_files:
+        changed_py_files = set()
+        config_changed = False
+        for d in (changes or []):
+            if d['uri'].endswith(PYTHON_FILE_EXTENSIONS):
+                changed_py_files.add(d['uri'])
+            elif d['uri'].endswith(CONFIG_FILEs):
+                config_changed = True
+
+        if config_changed:
+            self.config.settings.cache_clear()
+        elif not changed_py_files:
+            # Only externally changed python files and lint configs may result in changed diagnostics.
             return
-        # TODO: We currently don't cache settings therefor we can just lint again.
-        # Here would be the right point to update the settings after a change to config files.
+
         for doc_uri in self.workspace.documents:
             # Changes in doc_uri are already handled by m_text_document__did_save
             if doc_uri not in changed_py_files:
